@@ -8,6 +8,8 @@ class FileIO(ABC):
         if 'name' in kw:
             # Get storage type from properties
             storage_type = get_asset_property(asset_name=kw['name'], property="storage_type")
+            if storage_type is None:
+                storage_type = "filesystem"
         elif len(args)>0:
             storage_type = get_asset_property(asset_name=args[0], property="storage_type")
         else:
